@@ -12,7 +12,10 @@ import cdktf._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@cdktf/provider-local", "0.1.56", __name__[0:-6], "provider-local@0.1.56.jsii.tgz"
+    "@cdktf/provider-local",
+    "0.2.144",
+    __name__[0:-6],
+    "provider-local@0.2.144.jsii.tgz",
 )
 
 __all__ = [
